/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.exception;

public class UpgradeRequiredException extends RetriableUpgradeException {
  private final long systemCatalogTimestamp;

  public UpgradeRequiredException() {
    this(Long.MIN_VALUE);
  }

  public UpgradeRequiredException(long systemCatalogTimeStamp) {
    super("Operation not allowed since cluster hasn't been upgraded. Call EXECUTE UPGRADE. ",
      SQLExceptionCode.UPGRADE_REQUIRED.getSQLState(),
      SQLExceptionCode.UPGRADE_REQUIRED.getErrorCode());
    this.systemCatalogTimestamp = systemCatalogTimeStamp;
  }

  public long getSystemCatalogTimeStamp() {
    return systemCatalogTimestamp;
  }

}
